This function sets the provided graph to be the context for tidygraph
algorithms, such as e.g. node_is_center(), for the duration of the current
environment. It automatically removes the graph once the environment exits.
.register_graph_context(graph, free = FALSE, env = parent.frame())A tbl_graph object
Should the active state of the graph be ignored?
The environment where the context should be active